# Generated by Django 5.2.3 on 2025-06-27 08:52

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="DomesticProfile",
            fields=[
                (
                    "smart_id",
                    models.UUIDField(
                        db_index=True, primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("first_name", models.CharField(max_length=128, verbose_name="Имя")),
                ("last_name", models.CharField(max_length=128, verbose_name="Фамилия")),
                (
                    "email",
                    models.EmailField(
                        max_length=128, unique=True, verbose_name="E-mail"
                    ),
                ),
                (
                    "phone",
                    models.CharField(
                        max_length=128, unique=True, verbose_name="Телефон"
                    ),
                ),
            ],
            options={
                "ordering": ["smart_id"],
            },
        ),
        migrations.CreateModel(
            name="InternationalProfile",
            fields=[
                (
                    "smart_id",
                    models.UUIDField(
                        db_index=True, primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("first_name", models.CharField(max_length=128, verbose_name="Имя")),
                ("last_name", models.CharField(max_length=128, verbose_name="Фамилия")),
                (
                    "email",
                    models.EmailField(
                        max_length=128, unique=True, verbose_name="E-mail"
                    ),
                ),
                (
                    "phone",
                    models.CharField(
                        max_length=128, unique=True, verbose_name="Телефон"
                    ),
                ),
            ],
            options={
                "ordering": ["smart_id"],
            },
        ),
    ]
